<?php

	############################################################################
	# 	
	#	Meteotemplate
	# 	http://www.meteotemplate.com
	# 	Free website template for weather enthusiasts
	# 	Author: Jachym
	#           Brno, Czech Republic
	# 	First release: 2015
	#
	############################################################################
	#
	#	UK Extremes
	#
	# 	Plugin showing UK extreme weather for previous day.
	#
	############################################################################
	#	Version and change log
	#
	# 	v1.0 - Mar 18, 2016
	# 		- initial release
	#	v2.0 - Jun 3, 2016
	#		- added possibility to sort geographically
	#		- bug fixes
	# 	v2.1 - Aug 14, 2017
	# 		- minor tweaks
	#
	############################################################################
	
	include("../../config.php");
	include($baseURL."css/design.php");
	include($baseURL."header.php");
	
	include("settings.php");

	$cacheTime = 0;
	
	if($metOfficeAPI==""){
		echo "Specify your MetOffice API key in settings.php";
		die();
	}
	
	$data = array();
	
	$url = "http://datapoint.metoffice.gov.uk/public/data/txt/wxobs/ukextremes/json/latest?key=".$metOfficeAPI;

	if(file_exists("cache/data.txt")){
		if (time()-filemtime("cache/data.txt") > 60 * $cacheTime) {
			unlink("cache/data.txt");
		}
	}

	if(file_exists("cache/data.txt")){
		$dataRaw = file_get_contents("cache/data.txt");
		$data = json_decode($dataRaw,true);
	}
	else { 
		$dataRaw = curl_get_contents($url);
		if(strlen($dataRaw)>5){
			$save = file_put_contents("cache/data.txt",$dataRaw);
			$data = json_decode($dataRaw,true);
		}
		else{
			unlink("cache/data.txt");
			echo "Data currently not available";
			die;
		}
	}
	
	$date = strtotime($data['UkExtremes']['extremeDate']);
	
	$IDs = array();
	
	foreach($data['UkExtremes']['Regions']['Region'] as $region){
		$extremes = array();
		$id = $region['id'];
		$name = $region['name'];
		$IDs[] = array(trim($id),trim($name));
		foreach($region['Extremes']['Extreme'] as $extreme){
			if($extreme['type']=="HMAXT"){
				$extremes['HTmax'] = array($extreme['$'],$extreme['locationName']);
			}
			if($extreme['type']=="LMAXT"){
				$extremes['LTmax'] = array($extreme['$'],$extreme['locationName']);
			}
			if($extreme['type']=="LMINT"){
				$extremes['LTmin'] = array($extreme['$'],$extreme['locationName']);
			}
			if($extreme['type']=="HRAIN"){
				$extremes['MaxR'] = array($extreme['$'],$extreme['locationName']);
			}
			if($extreme['type']=="HSUN"){
				$extremes['MaxS'] = array($extreme['$'],$extreme['locationName']);
			}
		}
		if($name == "London & South East England"){
			$geoOrder = 0;
		}
		else if($name == "South West England"){
			$geoOrder = 1;
		}
		else if($name == "Wales"){
			$geoOrder = 2;
		}
		else if($name == "West Midlands"){
			$geoOrder = 3;
		}
		else if($name == "East Midlands"){
			$geoOrder = 4;
		}
		else if($name == "East of England"){
			$geoOrder = 5;
		}
		else if($name == "North West England"){
			$geoOrder = 6;
		}
		else if($name == "North East England"){
			$geoOrder = 7;
		}
		else if($name == "Yorkshire & Humber"){
			$geoOrder = 8;
		}
		else if($name == "Dumfries,Galloway,Lothian & Borders"){
			$geoOrder = 9;
		}
		else if($name == "Strathclyde"){
			$geoOrder = 10;
		}
		else if($name == "Central Tayside & Fife"){
			$geoOrder = 11;
		}
		else if($name == "Grampian"){
			$geoOrder = 12;
		}
		else if($name == "Highland & Eilean Siar"){
			$geoOrder = 13;
		}
		else if($name == "Orkney & Shetland"){
			$geoOrder = 14;
		}
		else if($name == "Northern Ireland"){
			$geoOrder = 15;
		}
		else if($name == "UK"){
			$geoOrder = 99;
		}
		else{
			$geoOrder = 16;
		}
		$regionArr = array($name,$extremes,$geoOrder);
		$resultData[$id] = $regionArr;
	}
	
	function sorter($a, $b) {
	  return $a[2] > $b[2];
	}
	uasort($resultData, "sorter");
?>
<!DOCTYPE html>
<html>
	<head>
		<title><?php echo $pageName?></title>
		<?php metaHeader()?>
		<script type="text/javascript" src="https://code.highcharts.com/highcharts.js"></script>
		<script type="text/javascript" src="https://code.highcharts.com/highcharts-more.js"></script>
		<script type="text/javascript" src="https://code.highcharts.com/modules/exporting.js"></script>
		<script type="text/javascript" src="<?php echo $pageURL.$path?>scripts/jquery.tablesorter.js"></script>
		<style>
			.thIcon{
				width:100%;
				max-width:40px;
			}
			.thIcon2{
				width:100%;
				width:60px;
			}
			.sort{
				width: 15px;
				cursor: pointer;
				opacity: 0.8;
			}
			.sort:hover{
				opacity: 1;
			}
			.table tfoot td{
				background: #<?php echo $color_schemes[$design2]['900']?>;
				font-weight: bold;
				font-variant: small-caps;
			}
		</style>
	</head>
	<body>
		<div id="main_top">
			<?php bodyHeader()?>
			<?php include($baseURL."menu.php")?>
		</div>
		<div id="main" style="text-align:center">
			<h1><img src="<?php echo $pageURL.$path?>imgs/flags/big/gb.png" style="width:100%;max-width:100px"><br><?php echo lang("extremes",'c')?></h1>
			<h2><?php echo date($dateFormat,$date)?></h2>
			<br>
			<br><br>
			<table style="width:90%;margin:0 auto" class="table" id="mainTable">
				<thead>
					<tr>
						<th style="text-align:center">
							<img src="ukDirection.png" class="thIcon2">
						</th>
						<th style="text-align:center">
							<img src="ukText.png" class="thIcon2">
						</th>
						<th style="text-align:center" colspan="2">
							<?php echo lang('maximumAbbr','l')?><br><img src="<?php echo $pageURL.$path?>icons/temp.png" class="thIcon"><br><?php echo lang('maximumAbbr','l')?><br>°C
						</th>
						<th style="text-align:center" colspan="2">
							<?php echo lang('maximumAbbr','l')?><br><img src="<?php echo $pageURL.$path?>icons/temp.png" class="thIcon"><br><?php echo lang('minimumAbbr','l')?><br>°C
						</th>
						<th style="text-align:center" colspan="2">
							<?php echo lang('minimumAbbr','l')?><br><img src="<?php echo $pageURL.$path?>icons/temp.png" class="thIcon"><br><?php echo lang('minimumAbbr','l')?><br>°C
						</th>
						<th style="text-align:center" colspan="2">
							<img src="<?php echo $pageURL.$path?>icons/rain.png" class="thIcon"><br><?php echo lang('maximumAbbr','l')?><br>mm
						</th>
						<th style="text-align:center" colspan="2">
							<img src="<?php echo $pageURL.$path?>icons/sun.png" class="thIcon"><br><?php echo lang('maximumAbbr','l')?><br><?php echo lang('hAbbr','l')?>
						</th>
					</tr>
					<tr>
						<th style="text-align:center">
							<img src="<?php echo $pageURL.$path?>icons/sort.png" class="sort" alt=''>
						</th>
						<th style="text-align:center">
							<img src="<?php echo $pageURL.$path?>icons/sort.png" class="sort" alt=''>
						</th>
						<th>
							<img src="<?php echo $pageURL.$path?>icons/sort.png" class="sort" alt=''>
						</th>
						<th>
						</th>
						<th>
							<img src="<?php echo $pageURL.$path?>icons/sort.png" class="sort" alt=''>
						</th>
						<th>
						</th>
						<th>
							<img src="<?php echo $pageURL.$path?>icons/sort.png" class="sort" alt=''>
						</th>
						<th>
						</th>
						<th>
							<img src="<?php echo $pageURL.$path?>icons/sort.png" class="sort" alt=''>
						</th>
						<th>
						</th>
						<th>
							<img src="<?php echo $pageURL.$path?>icons/sort.png" class="sort" alt=''>
						</th>
						<th>
						</th>
					</tr>
				</thead>
				<tbody>
					<?php
						foreach($resultData as $key=>$region){
							if($key!='uk'){
					?>
								<tr>
									<td style="font-variant:small-caps;background: #<?php echo $color_schemes[$design2]['900']?>;font-size:0px">
										<?php echo $region[2]?>
									</td>
									<td style="font-variant:small-caps;background: #<?php echo $color_schemes[$design2]['900']?>;font-weight:bold;text-align:left">
										<?php echo $region[0]?>
									</td>
									<td style="width:10%">
										<?php 
											if(array_key_exists('HTmax',$region[1])){
												echo $region[1]['HTmax'][0];
											}
										?>
									</td>
									<td style="width:10%;text-align:left">
										<?php 
											if(array_key_exists('HTmax',$region[1])){
												echo $region[1]['HTmax'][1];
											}
										?>
									</td>
									<td style="width:10%">
										<?php 
											if(array_key_exists('LTmax',$region[1])){
												echo $region[1]['LTmax'][0];
											}
										?>
									</td>
									<td style="width:10%;text-align:left">
										<?php 
											if(array_key_exists('LTmax',$region[1])){
												echo $region[1]['LTmax'][1];
											}
										?>
									</td>
									<td style="width:10%">
										<?php 
											if(array_key_exists('LTmin',$region[1])){
												echo $region[1]['LTmin'][0];
											}
										?>
									</td>
									<td style="width:10%;text-align:left">
										<?php 
											if(array_key_exists('LTmin',$region[1])){
												echo $region[1]['LTmin'][1];
											}
										?>
									</td>
									<td style="width:10%">
										<?php 
											if(array_key_exists('MaxR',$region[1])){
												echo $region[1]['MaxR'][0];
											}
										?>
									</td>
									<td style="width:10%;text-align:left">
										<?php 
											if(array_key_exists('MaxR',$region[1])){
												echo $region[1]['MaxR'][1];
											}
										?>
									</td>
									<td style="width:10%">
										<?php 
											if(array_key_exists('MaxS',$region[1])){
												echo $region[1]['MaxS'][0];
											}
										?>
									</td>
									<td style="width:10%;text-align:left">
										<?php 
											if(array_key_exists('MaxS',$region[1])){
												echo $region[1]['MaxS'][1];
											}
										?>
									</td>
								</tr>
					<?php
							}
						}
					?>
				</tbody>
				<tfoot>
					<tr>
						<td></td>
						<td style="text-align:left">
							UK
						</td>
						<td>
							<?php 
								if(array_key_exists('HTmax',$resultData['uk'][1])){
									echo $resultData['uk'][1]['HTmax'][0];
								}
							?>
						</td>
						<td style="width:10%;text-align:left">
							<?php 
								if(array_key_exists('HTmax',$resultData['uk'][1])){
									echo $resultData['uk'][1]['HTmax'][1];
								}
							?>
						</td>
						<td>
							<?php 
								if(array_key_exists('LTmax',$resultData['uk'][1])){
									echo $resultData['uk'][1]['LTmax'][0];
								}
							?>
						</td>
						<td style="width:10%;text-align:left">
							<?php 
								if(array_key_exists('LTmax',$resultData['uk'][1])){
									echo $resultData['uk'][1]['LTmax'][1];
								}
							?>
						</td>
						<td>
							<?php 
								if(array_key_exists('LTmin',$resultData['uk'][1])){
									echo $resultData['uk'][1]['LTmin'][0];
								}
							?>
						</td>
						<td style="width:10%;text-align:left">
							<?php 
								if(array_key_exists('LTmin',$resultData['uk'][1])){
									echo $resultData['uk'][1]['LTmin'][1];
								}
							?>
						</td>
						<td>
							<?php 
								if(array_key_exists('MaxR',$resultData['uk'][1])){
									echo $resultData['uk'][1]['MaxR'][0];
								}
							?>
						</td>
						<td style="width:10%;text-align:left">
							<?php 
								if(array_key_exists('MaxR',$resultData['uk'][1])){
									echo $resultData['uk'][1]['MaxR'][1];
								}
							?>
						</td>
						<td>
							<?php 
								if(array_key_exists('MaxS',$resultData['uk'][1])){
									echo $resultData['uk'][1]['MaxS'][0];
								}
							?>
						</td>
						<td style="width:10%;text-align:left">
							<?php 
								if(array_key_exists('MaxS',$resultData['uk'][1])){
									echo $resultData['uk'][1]['MaxS'][1];
								}
							?>
						</td>
					</tr>
				</tfoot>
			</table>
			<br>
			<div id="maxmaxT" style="height:400px;width:90%;margin:0 auto;"></div>
			<br>
			<div id="minmaxT" style="height:400px;width:90%;margin:0 auto;"></div>
			<br>
			<div id="minminT" style="height:400px;width:90%;margin:0 auto;"></div>
			<br>
			<div id="maxR" style="height:400px;width:90%;margin:0 auto;"></div>
			<br>
			<div id="maxS" style="height:400px;width:90%;margin:0 auto;"></div>
			<br>
			<div style="width:90%;margin:0 auto;text-align:left;font-size:0.9em">
				<ul>
					<li>highest maximum temperature - (09:00 to 21:00 on the date shown)</li>
					<li>lowest maximum temperature - (09:00 to 21:00 on the date shown)</li>
					<li>lowest minimum temperature - (21:00 on the previous day to 09:00 on the date shown)</li>
					<li>highest rainfall - (21:00 on the previous day to 21:00 on the date shown)</li>
					<li>sunniest - (21:00 on the previous day to 21:00 on the date shown)</li>
				</ul>
			</div>
			<br><br>
			<div style="width:100%;text-align:center;font-size:0.8em">Contains public sector information licensed under the Open Government Licence</div>
			<br>
		</div>
		<?php include($baseURL."footer.php")?>
		<script>
			$("#mainTable").tablesorter();
		</script>
		<script>
			Highcharts.createElement('link', {
				href: 'https://fonts.googleapis.com/css?family=PT+Sans:400,700&subset=latin,cyrillic-ext,latin-ext',
				rel: 'stylesheet',
				type: 'text/css'
			}, null, document.getElementsByTagName('head')[0]);

			Highcharts.theme = {
				colors: ["#BBBBBB", "#90ee7e", "#f45b5b", "#7798BF", "#aaeeee", "#ff0066", "#eeaaee",
					"#55BF3B", "#DF5353", "#7798BF", "#aaeeee"],
				chart: {
					backgroundColor: null,
					color: "#<?php echo $color_schemes[$design2]['font900']?>",
					style: {
						fontFamily: "'<?php echo $designFont?> Narrow', sans-serif",
						fontSize: '18px'
					},
					plotBorderColor: '#606063'
				},
				title: {
					style: {
						color: "#<?php echo $color_schemes[$design2]['font900']?>",
						textTransform: 'uppercase',
						fontSize: '20px'
					}
				},
				subtitle: {
					style: {
						color: '#E0E0E3',
						textTransform: 'uppercase'
					}
				},
				xAxis: {
					gridLineColor: '#<?php echo $color_schemes[$design2]['font900']?>',
					labels: {
						style: {
							color: '#<?php echo $color_schemes[$design2]['font900']?>'
						}
					},
					lineColor: '#<?php echo $color_schemes[$design2]['font900']?>',
					minorGridLineColor: '#<?php echo $color_schemes[$design2]['font900']?>',
					tickColor: '#<?php echo $color_schemes[$design2]['font900']?>',
					title: {
						style: {
							color: '#<?php echo $color_schemes[$design2]['font900']?>'

						}
					}
				},
				yAxis: {
					gridLineColor: '#<?php echo $color_schemes[$design2]['font900']?>',
					gridLineWidth: 0,
					labels: {
						style: {
							color: '#<?php echo $color_schemes[$design2]['font900']?>'
						}
					},
					lineColor: '#<?php echo $color_schemes[$design2]['font900']?>',
					minorGridLineColor: '#<?php echo $color_schemes[$design2]['font900']?>',
					tickColor: '#<?php echo $color_schemes[$design2]['font900']?>',
					tickWidth: 1,
					title: {
						style: {
							color: '#<?php echo $color_schemes[$design2]['font900']?>'
						}
					}
				},
				tooltip: {
					backgroundColor: '#<?php echo $color_schemes[$design2]['700']?>',
					style: {
						color: '#<?php echo $color_schemes[$design2]['font700']?>',
						fontSize: '17px'
					}
				},
				plotOptions: {
					series: {
						dataLabels: {
							color: '#<?php echo $color_schemes[$design2]['100']?>'
						},
						marker: {
							lineColor: '#333'
						}
					},
					boxplot: {
						fillColor: '#505053'
					},
					candlestick: {
						lineColor: 'white'
					},
					errorbar: {
						color: 'white'
					}
				},
				legend: {
					itemStyle: {
						color: '#<?php echo $color_schemes[$design2]['200']?>',
						fontSize: '14px',
					},
					itemHoverStyle: {
						color: '#<?php echo $color_schemes[$design2]['300']?>'
					},
					itemHiddenStyle: {
						color: '#<?php echo $color_schemes[$design2]['600']?>'
					}
				},
				credits: {
					style: {
						color: '#666'
					}
				},
				labels: {
					style: {
						color: '#707073'
					}
				},

				drilldown: {
					activeAxisLabelStyle: {
						color: '#F0F0F3'
					},
					activeDataLabelStyle: {
						color: '#F0F0F3'
					}
				},

				navigation: {
					buttonOptions: {
						symbolStroke: '#DDDDDD',
						theme: {
							fill: '#505053'
						}
					}
				},

				// scroll charts
				rangeSelector: {
					buttonTheme: {
						fill: '#505053',
						stroke: '#000000',
						style: {
							color: '#CCC'
						},
						states: {
							hover: {
								fill: '#707073',
								stroke: '#000000',
								style: {
									color: 'white'
								}
							},
							select: {
								fill: '#000003',
								stroke: '#000000',
								style: {
									color: 'white'
								}
							}
						}
					},
					inputBoxBorderColor: '#505053',
					inputStyle: {
						backgroundColor: '#333',
						color: 'silver'
					},
					labelStyle: {
						color: 'silver'
					}
				},

				navigator: {
					handles: {
						backgroundColor: '#666',
						borderColor: '#AAA'
					},
					outlineColor: '#CCC',
					maskFill: 'rgba(255,255,255,0.1)',
					series: {
						color: '#7798BF',
						lineColor: '#A6C7ED'
					},
					xAxis: {
						gridLineColor: '#505053'
					}
				},

				scrollbar: {
					barBackgroundColor: '#808083',
					barBorderColor: '#808083',
					buttonArrowColor: '#CCC',
					buttonBackgroundColor: '#606063',
					buttonBorderColor: '#606063',
					rifleColor: '#FFF',
					trackBackgroundColor: '#404043',
					trackBorderColor: '#404043'
				},

				// special colors for some of the
				legendBackgroundColor: 'rgba(0, 0, 0, 0.5)',
				background2: '#505053',
				dataLabelsColor: '#B0B0B3',
				textColor: '#C0C0C0',
				contrastTextColor: '#F0F0F3',
				maskColor: 'rgba(255,255,255,0.3)'
			};

			// Apply the theme
			Highcharts.setOptions(Highcharts.theme);
		</script>
		<script>
			Highcharts.setOptions({
				global: {
					useUTC: true
				},
				lang: {
					months: ['<?php echo lang('january','c')?>', '<?php echo lang('february','c')?>', '<?php echo lang('march','c')?>', '<?php echo lang('april','c')?>', '<?php echo lang('may','c')?>', '<?php echo lang('june','c')?>', '<?php echo lang('july','c')?>', '<?php echo lang('august','c')?>', '<?php echo lang('september','c')?>', '<?php echo lang('october','c')?>', '<?php echo lang('november','c')?>', '<?php echo lang('december','c')?>'],
					shortMonths: ['<?php echo lang('janAbbr','c')?>', '<?php echo lang('febAbbr','c')?>', '<?php echo lang('marAbbr','c')?>', '<?php echo lang('aprAbbr','c')?>', '<?php echo lang('mayAbbr','c')?>', '<?php echo lang('junAbbr','c')?>', '<?php echo lang('julAbbr','c')?>', '<?php echo lang('augAbbr','c')?>', '<?php echo lang('sepAbbr','c')?>', '<?php echo lang('octAbbr','c')?>', '<?php echo lang('novAbbr','c')?>', '<?php echo lang('decAbbr','c')?>'],
					weekdays: ['<?php echo lang('sundayAbbr','c')?>', '<?php echo lang('mondayAbbr','c')?>', '<?php echo lang('tuesdayAbbr','c')?>', '<?php echo lang('wednesdayAbbr','c')?>', '<?php echo lang('thursdayAbbr','c')?>', '<?php echo lang('fridayAbbr','c')?>', '<?php echo lang('saturdayAbbr','c')?>'],
					resetZoom: ['<?php echo lang('default zoom','c')?>']
				}		
			});
			$('#maxmaxT').highcharts({
				chart: {
					type: 'spline',
					backgroundColor: '#<?php echo $color_schemes[$design2]['900']?>',
				},
				title: {
					text: '<?php echo lang('maximum','c')." ".lang('maximum','l')." ".lang('temperature','l')?>'
				},
				tooltip: {
					enabled: true,
					shared: true,
				},
				xAxis: {
					categories: [
						<?php 
							foreach($resultData as $result){
								echo "'".$result[0]."',";
							}
						?>
					]
				},
				legend: {
					enabled: false,
				},
				yAxis: [
					{
						title: {
							text: "°C"
						},
					}
				],
				exporting: {
					enabled: true
				},
				plotOptions: {
					series: {
						animation: {
							duration: 300
						},
						marker: {
							enabled: false
						}
					},					
				},
				series: [
					{
						name: 'Highest maximum temperature',
						color: '#FFFFFF',
						lineWidth: 0,
						marker: {
							enabled: true,
							radius: 5,
						},
						data: [
							<?php
								foreach($resultData as $key=>$region){
									if($key!='uk'){
										if(array_key_exists('HTmax',$region[1])){
												echo $region[1]['HTmax'][0].",";
										}
										else{
											echo "null,";
										}
									}
								}
								if(isset($resultData['uk'][1]['HTmax'][0])){
									echo $resultData['uk'][1]['HTmax'][0];
								}
							?>
						]
					},
				]
			});
			$('#minmaxT').highcharts({
				chart: {
					type: 'spline',
					backgroundColor: '#<?php echo $color_schemes[$design2]['900']?>',
				},
				title: {
					text: '<?php echo lang('minimum','c')." ".lang('maximum','l')." ".lang('temperature','l')?>'
				},
				tooltip: {
					enabled: true,
					shared: true,
				},
				xAxis: {
					categories: [
						<?php 
							foreach($resultData as $result){
								echo "'".$result[0]."',";
							}
						?>
					
					]
				},
				legend: {
					enabled: false,
				},
				yAxis: [
					{
						title: {
							text: "°C"
						},
					}
				],
				exporting: {
					enabled: true
				},
				plotOptions: {
					series: {
						animation: {
							duration: 300
						},
						marker: {
							enabled: false
						}
					},					
				},
				series: [
					{
						name: 'Lowest maximum temperature',
						color: '#FFFFFF',
						lineWidth: 0,
						marker: {
							enabled: true,
							radius: 5,
						},
						data: [
							<?php
								foreach($resultData as $key=>$region){
									if($key!='uk'){
										if(array_key_exists('LTmax',$region[1])){
												echo $region[1]['LTmax'][0].",";
										}
										else{
											echo "null,";
										}
									}
								}
								if(isset($resultData['uk'][1]['LTmax'][0])){
									echo $resultData['uk'][1]['LTmax'][0];
								}
							?>
						]
					},
				]
			});
			$('#minminT').highcharts({
				chart: {
					type: 'spline',
					backgroundColor: '#<?php echo $color_schemes[$design2]['900']?>',
				},
				title: {
					text: '<?php echo lang('minimum','c')." ".lang('minimum','l')." ".lang('temperature','l')?>'
				},
				tooltip: {
					enabled: true,
					shared: true,
				},
				xAxis: {
					categories: [
						<?php 
							foreach($resultData as $result){
								echo "'".$result[0]."',";
							}
						?>
					
					]
				},
				legend: {
					enabled: false,
				},
				yAxis: [
					{
						title: {
							text: "°C"
						},
					}
				],
				exporting: {
					enabled: true
				},
				plotOptions: {
					series: {
						animation: {
							duration: 300
						},
						marker: {
							enabled: false
						}
					},					
				},
				series: [
					{
						name: 'Lowest minimum temperature',
						color: '#FFFFFF',
						lineWidth: 0,
						marker: {
							enabled: true,
							radius: 5,
						},
						data: [
							<?php
								foreach($resultData as $key=>$region){
									if($key!='uk'){
										if(array_key_exists('LTmin',$region[1])){
												echo $region[1]['LTmin'][0].",";
										}
										else{
											echo "null,";
										}
									}
								}
								if(isset($resultData['uk'][1]['LTmin'][0])){
									echo $resultData['uk'][1]['LTmin'][0];
								}
							?>
						]
					},
				]
			});
			$('#maxR').highcharts({
				chart: {
					type: 'column',
					backgroundColor: '#<?php echo $color_schemes[$design2]['900']?>',
				},
				title: {
					text: '<?php echo lang('maximum','c')." ".lang('precipitation','l')?>'
				},
				tooltip: {
					enabled: true,
					shared: true,
				},
				xAxis: {
					categories: [
						<?php 
							foreach($resultData as $result){
								echo "'".$result[0]."',";
							}
						?>
					
					]
				},
				legend: {
					enabled: false,
				},
				yAxis: [
					{
						title: {
							text: "mm"
						},
						min: 0,
					}
				],
				exporting: {
					enabled: true
				},
				plotOptions: {
					series: {
						animation: {
							duration: 300
						},
						marker: {
							enabled: false
						}
					},					
				},
				series: [
					{
						name: 'Highest rainfall',
						color: '#FFFFFF',
						data: [
							<?php
								foreach($resultData as $key=>$region){
									if($key!='uk'){
										if(array_key_exists('MaxR',$region[1])){
												echo $region[1]['MaxR'][0].",";
										}
										else{
											echo "null,";
										}
									}
								}
								if(isset($resultData['uk'][1]['MaxR'][0])){
									echo $resultData['uk'][1]['MaxR'][0];
								}
							?>
						]
					},
				]
			});
			$('#maxS').highcharts({
				chart: {
					type: 'column',
					backgroundColor: '#<?php echo $color_schemes[$design2]['900']?>',
				},
				title: {
					text: '<?php echo lang('maximum','c')." ".lang('sun','l')?>'
				},
				tooltip: {
					enabled: true,
					shared: true,
				},
				xAxis: {
					categories: [
						<?php 
							foreach($resultData as $result){
								echo "'".$result[0]."',";
							}
						?>
					
					]
				},
				legend: {
					enabled: false,
				},
				yAxis: [
					{
						title: {
							text: "<?php echo lang('hAbbr','l')?>"
						},
						min: 0,
					}
				],
				exporting: {
					enabled: true
				},
				plotOptions: {
					series: {
						animation: {
							duration: 300
						},
						marker: {
							enabled: false
						}
					},					
				},
				series: [
					{
						name: 'Sunniest',
						color: '#FFFFFF',
						data: [
							<?php
								foreach($resultData as $key=>$region){
									if($key!='uk'){
										if(array_key_exists('MaxS',$region[1])){
												echo $region[1]['MaxS'][0].",";
										}
										else{
											echo "null,";
										}
									}
								}
								if(isset($resultData['uk'][1]['MaxS'][0])){
									echo $resultData['uk'][1]['MaxS'][0];
								}
							?>
						]
					},
				]
			});
		</script>
		
	</body>
</html>
	